# encoding: utf-8

if RUBY_VERSION > '1.9' and (ENV['COVERAGE'] || ENV['TRAVIS'])
  require 'simplecov'
  require 'coveralls'

  SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[
    SimpleCov::Formatter::HTMLFormatter,
    Coveralls::SimpleCov::Formatter
  ]

  SimpleCov.start do
    command_name 'spec'
    add_filter 'spec'
  end
end

require 'supervision'
require 'timeout'

module Helpers
  def wait_for(duration = nil)
    Timeout.timeout 1 do
      sleep(duration || 0.01) until yield
    end
  end

  def spawn(threads = 2)
    threads.times.map do |i|
      Thread.new do
        yield i
      end
    end.each do |thread|
      thread.join
    end
  end
end

RSpec.configure do |config|
  config.treat_symbols_as_metadata_keys_with_true_values = true
  config.run_all_when_everything_filtered = true
  config.filter_run :focus
  config.order = 'random'
  config.include Helpers
end
